require "asm/private_util"
require "asm/network_configuration"

module ASM
  module Processor
    class WindowsVMPostOS < ASM::Processor::WinPostOS
      def post_os_resources
        appliance_ip = host_ip_config(@resource.network_interfaces)
        {"host" => {"dellasm" => {"ensure" => "present", "ip" => appliance_ip}}}
      end

      def post_os_classes(puppet_hash={})
        # NIC IP Configuration
        puppet_hash = puppet_hash.merge(nic_ip_config(puppet_hash))
        logger.debug("Puppet hash after NIC IP Configuration: %s" % puppet_hash.inspect)

        # Domain Configuration
        logger.debug("Puppet hash before domain config: %s" % puppet_hash.inspect)
        puppet_hash = puppet_hash.merge(domain_config(puppet_hash))
        logger.debug("Domain Config: %s" % puppet_hash.inspect)

        # Cleanup
        puppet_hash = puppet_hash.merge(cleanup(puppet_hash))
        logger.debug("Puppet hash after cleanup configuration: %s" % puppet_hash.inspect)

        puppet_hash
      end

      def nic_ip_config(puppet_hash)
        adapter_ip_info = []
        non_team_nic_ip_hash = {}
        @resource.network_interfaces.each do |workload_network|
          hash_network = Hashie::Mash.new(workload_network)
          logger.debug("VM Network workload network: #{hash_network}")
          vm_mac_address = @resource.macaddress(hash_network)
          adapter_ip_info.push(network_ip_info(hash_network,
                                               hash_network.name,
                                               vm_mac_address.tr(":", "-")))
        end
        logger.debug("Network adapter info #{adapter_ip_info}")
        unless adapter_ip_info.empty?
          adapter_ip_info = adapter_ip_info.join(";") if windows_2008?
          non_team_nic_ip_hash["windows_postinstall::nic::adapter_nic_ip_settings"] = {}
          non_team_nic_ip_hash["windows_postinstall::nic::adapter_nic_ip_settings"] = {
            "ipaddress_info" => {"NICIPInfo" => adapter_ip_info}
          }
          unless puppet_hash.keys.empty?
            non_team_nic_ip_hash["windows_postinstall::nic::adapter_nic_ip_settings"]["require"] = capitalize(puppet_hash.keys)
          end
        end
        puppet_hash.merge(non_team_nic_ip_hash)
      end

      def windows_2008?
        logger.debug("Checking for Windows 2008 for Windows VM")
        if @resource.os_image_version.nil?
          os_image_type = @resource.os_image_type
          logger.debug("OS Image version not available for vm %s. Check vm os type using native API %s" % [@resource.agent_certname, os_image_type])
          os_image_type.match(/windows7|2008/i)
        else
          logger.debug("OS Image version %s" % @resource.os_image_version)
          @resource.os_image_version.match(/2008/)
        end
      end

      def cleanup(puppet_hash={})
        cleanup_hash = {
          "windows_postinstall::cleanup::cleanup" => {}
        }
        logger.debug("Returning cleanup hash : #{cleanup_hash}")
        cleanup_hash
      end
    end
  end
end
