require "asm/provider/switch/force10/base"
require "base64"

module ASM
  class Provider
    class Switch
      class Force10
        # Manages quadport_mode for both mxl and Ioa switches
        # This calls has a generic behavior for configuring Quad_port_mode
        # for both MXL and IOA switches.
        class Iom < Base
          def initialize(provider, resources={})
            @interfaces = []
            @resources = resources
            @provider = provider
            @logger = provider.logger
            @type = provider.type
            @sequence = nil
          end

          # Configures a list of interfaces for quodmode
          #
          # Only 40 Gb interfaces can be part of a group, any non 40 Gb interfaces
          # listed when enable is true will be silently skipped and logged
          #
          # @param interfaces [Array,nil] list of interfaces, when nil will use the quad_port_interfaces fact
          # @param enable [Boolean] should it be enabled or not for quadmode
          # @param reboot [Boolean] should the last interface set reboot required
          # @return [void]
          def configure_quadmode(interfaces, enable, reboot=true)
            interfaces ||= provider.facts["quad_port_interfaces"]

            if interfaces.empty?
              logger.debug("Could not find any interfaces to configure quadmode on")
              return
            end

            port_resources["mxl_quadmode"] ||= {}

            eligible_interfaces = interfaces.select { |i| !enable || forty_gb_interface?(i) }

            (interfaces - eligible_interfaces).each do |interface|
              logger.warn("Interface %s/%s requested to be configured for quad mode but its not a 40 gig interface, skipping" % [type.puppet_certname, interface])
            end

            eligible_interfaces.each do |interface|
              if enable && !forty_gb_interface?(interface)
                logger.warn("Interface %s/%s requested to be configured for quad mode but its not a 40 gig interface, skipping" % [type.puppet_certname, interface])
                next
              end

              resource = port_resources["mxl_quadmode"][interface] = {}

              resource["ensure"] = enable ? "present" : "absent"

              if reboot && interface == eligible_interfaces.last
                resource["reboot_required"] = "true"
              end

              resource["require"] = sequence if sequence
              @sequence = "Mxl_quadmode[%s]" % interface
            end
          end

          # Determines if an interface name is a 40Gb interface
          #
          # @param interface [String] the interface name
          # @return [Boolean]
          def forty_gb_interface?(interface)
            !!interface.match(/^fo/i)
          end
        end
      end
    end
  end
end
