#!/opt/puppet/bin/ruby

require 'trollop'
require 'json'
require 'winrm'

@opts = Trollop::options do
  opt :server, 'server address', :type => :string
  opt :username, 'server username', :type => :string
  opt :domain, 'server domain', :type => :string
  opt :fqdn, 'server domain fqdn', :type => :string
  opt :password, 'server password', :type => :string
end

def check_https_enabled
  enabled = true
  require "net/http"
  url = URI.parse("https://#{@opts[:server]}:5986/wsman")
  req = Net::HTTP.new(url.host, url.port)
  begin
    req.use_ssl = true
    req.verify_mode = 0
    req.request_head(url.path)
  rescue
    enabled = false
  end
  enabled
end

def winrm_http
  endpoint = "http://#{@opts[:server]}:5985/wsman"
  WinRM::WinRMWebService.new(
      endpoint, :plaintext,
      :user => "#{@opts[:domain]}\\#{@opts[:username]}",
      :pass => @opts[:password],
      :disable_sspi => true
  )
end

def winrm_https
  endpoint = "http://#{@opts[:server]}:5986/wsman"
  WinRM::WinRMWebService.new(
      endpoint, :ssl,
      :user => "#{@opts[:domain]}\\#{@opts[:username]}",
      :pass => @opts[:password],
      :disable_sspi => true,
      :no_ssl_peer_verification => true
  )
end

https_enabled = check_https_enabled
puts "Enabled status: #{https_enabled}"
unless https_enabled
  begin
    result = winrm_http.create_executor.run_powershell_script("New-NetFirewallRule -DisplayName \"WinRM HTTPS\" -Action Allow -AsJob -Enabled True -LocalPort 5986 -Protocol TCP -Direction InBound; Write-Host(\"FQDN: #{@opts[:fqdn]}\"); $DNSName = \"$env:computername.#{@opts[:fqdn]}\"; Write-host(\"DNSName: $DNSName\"); $cert = New-SelfSignedCertificate -DnsName $DNSName -CertStoreLocation Cert:\\LocalMachine\\My; Write-Host(\"Cert Name: $cert\"); $thumbprint = $cert.thumbprint; Write-Host(\"Thumb Print: $thumbprint\"); $cmd = \"winrm create winrm/config/Listener?Address=*+Transport=HTTPS @{Hostname=\\`\"$DNSName\\`\";CertificateThumbprint=\\`\"$thumbprint\\`\"}\"; Write-host(\"CMD: $cmd\"); cmd /c $cmd; winrm quickconfig -transport:https")
    stdout = result[:data].collect{|l| l[:stdout]}.join
    puts "STDOUT: #{stdout}"
  rescue WinRM::WinRMAuthorizationError
    puts "Server is not added to the domain"
    exit 2
  end

end
exit 0