require "spec_helper"
require "asm/provider/switch/force10/iom"

describe ASM::Provider::Switch::Force10::Iom do
  let(:logger) { stub(:debug => nil, :warn => nil, :info => nil) }
  let(:type) { stub(:puppet_certname => "rspec") }
  let(:provider) { stub(:type => type, :logger => logger, :mtu => "9216") }
  let(:blade) { ASM::Provider::Switch::Force10::Iom.new(provider) }
  let(:resource_hash) do
    {"ensure" => "present",
     "reboot_required" => "true"
    }
  end

  describe "#configure_quadmode" do
    let(:resource_result) do
      {"ensure" => "absent"}
    end
    let(:resource_result2) do
      {"ensure" => "absent",
       "reboot_required" => "true",
       "require" => "Mxl_quadmode[Fo 0/0]"
      }
    end
    it "should disable quoadmode on any interface" do
      blade.configure_quadmode(["Fo 0/0", "Te 0/0"], false)
      expect(blade.port_resources["mxl_quadmode"]["Fo 0/0"]).to eq(resource_result)
      expect(blade.port_resources["mxl_quadmode"]["Te 0/0"]).to eq(resource_result2)
    end

    it "should not enable quad mode on non 40gb interfaces" do
      blade.configure_quadmode(["Fo 0/0", "Te 0/0"], true)
      expect(blade.port_resources["mxl_quadmode"]["Fo 0/0"]).to eq(resource_hash)
      expect(blade.port_resources["mxl_quadmode"]).to_not include("Te 0/0")
    end
  end

  describe "#forty_gb_interface?" do
    it "should correctly determine if it's a 40Gb int" do
      expect(blade.forty_gb_interface?("Fo 0/1")).to be(true)
      expect(blade.forty_gb_interface?("Te 0/1")).to be(false)
    end
  end
end
