desc "Run rubocop style and lint checks"
task :rubocop do
  if RUBY_PLATFORM == "java" && !ENV["FORCE_RUBOCOP"]
    puts "Skipping rubocop runs on java"
    next
  end

  all_files = Dir.glob("**/*.rb")

  excluded_files = [
    "app.rb",
    "db/migrate/001_create_base_schema.rb",
    "lib/asm/api.rb",
    "lib/asm/appliance_setup/dhcp.rb",
    "lib/asm/cipher.rb",
    "lib/asm/client.rb",
    "lib/asm/config.rb",
    "lib/asm/deployment_teardown.rb",
    "lib/asm/device_metrics.rb",
    "lib/asm/discoverswitch.rb",
    "lib/asm/graphite.rb",
    "lib/asm/item_validator.rb",
    "lib/asm/logger_format.rb",
    "lib/asm/messaging/job_processor.rb",
    "lib/asm/messaging.rb",
    "lib/asm/monitoring.rb",
    "lib/asm/private_util.rb",
    "lib/asm/processor/linux_post_os.rb",
    "lib/asm/razor.rb",
    "lib/asm.rb",
    "lib/asm/resource.rb",
    "lib/asm/scvmm_cluster_information.rb",
    "lib/asm/scvmm_cluster_ip.rb",
    "lib/asm/scvmm_macaddress.rb",
    "lib/asm/scvmm_vminfo.rb",
    "lib/asm/scvmm_vm_nic_info.rb",
    "lib/asm/secrets.rb",
    "lib/asm/service_deployment.rb",
    "lib/asm/service_migration_deployment.rb",
    "lib/asm/update_deployment.rb",
    "lib/asm/winrm_reconfigure.rb",
    "nagios/check-ipmi.rb",
    "nagios/check-racadm.rb",
    "nagios/check_snmp.rb",
    "nagios/check-wsman.rb",
    "nagios/nagios-export.rb",
    "nagios/poll_idrac8_sensors.rb",
    "nagios/process_nagios_status.rb",
    "scripts/decrypt_secretid.rb",
    "scripts/puppet_certname.rb",
    "spec/config_spec.rb",
    "spec/db/asm/data/deployment_spec.rb",
    "spec/soft_integration/service_runner.rb",
    "spec/spec_helper.rb",
    "spec/unit/asm/private_util_spec.rb",
    "spec/unit/asm/processor/linux_post_os_spec.rb",
    "spec/unit/asm/processor/linux_vm_post_os_spec.rb",
    "spec/unit/asm/processor/post_os_spec.rb",
    "spec/unit/asm/processor/server_spec.rb",
    "spec/unit/asm/processor/windows_vm_post_os_spec.rb",
    "spec/unit/asm/processor/win_post_os_spec.rb",
    "spec/unit/asm/provider/switch/nexus5k/rack_spec.rb",
    "spec/unit/asm/provider/switch/nexus5k_spec.rb",
    "spec/unit/asm/provider/switch/powerconnect/rack_spec.rb",
    "spec/unit/asm/provider/switch/powerconnect_spec.rb",
    "spec/unit/asm/provider/virtualmachine/scvmm_spec.rb",
    "spec/unit/asm/provider/virtualmachine/vmware_spec.rb",
    "spec/unit/asm/provider/volume/compellent_spec.rb",
    "spec/unit/asm/provider/volume/netapp_spec.rb",
    "spec/unit/asm/provider/volume/vnx_spec.rb",
    "spec/unit/asm/resource_spec.rb",
    "spec/unit/asm/rule_engine/result_spec.rb",
    "spec/unit/asm/rule_engine/rule_evaluator_spec.rb",
    "spec/unit/asm/rule_engine/rule_spec.rb",
    "spec/unit/asm/rule_engine/rules_spec.rb",
    "spec/unit/asm/rule_engine_spec.rb",
    "spec/unit/asm/rule_engine/state_spec.rb",
    "spec/unit/asm/secrets_spec.rb",
    "spec/unit/asm/service/component/generator_spec.rb",
    "spec/unit/asm/service/component/resource_spec.rb",
    "spec/unit/asm/service/component_spec.rb",
    "spec/unit/asm/service_deployment_spec.rb",
    "spec/unit/asm/service/processor_spec.rb",
    "spec/unit/asm/service_spec.rb",
    "spec/unit/asm/service/switch_collection_spec.rb",
    "spec/unit/asm_spec.rb",
    "spec/unit/asm/translatable_spec.rb",
    "spec/unit/asm/type/base_spec.rb",
    "spec/unit/asm/type/cluster_spec.rb",
    "spec/unit/asm/type/controller_spec.rb",
    "spec/unit/asm/type_spec.rb",
    "spec/unit/asm/type/switch_spec.rb",
    "spec/unit/asm/type/virtualmachine_spec.rb",
    "spec/unit/asm/type/volume_spec.rb",
    "spec/unit/asm/update_deployment_spec.rb",
    "spec/unit/asm/util_spec.rb",
    "spec/unit/rules/component_common/pre_flight_rule_spec.rb",
    "spec/unit/rules/migration/server_migration_rule_spec.rb",
    "spec/unit/rules/service/cluster_lane_teardown_rule_spec.rb",
    "spec/unit/rules/teardown/cluster_teardown_rule_spec.rb",
    "spec/unit/rules/teardown/prepare_teardown_rule_spec.rb",
    "spec/unit/rules/teardown/server_teardown_rule_spec.rb",
    "spec/unit/rules/teardown/virtualmachine_teardown_rule_spec.rb",
    "spec/unit/rules/teardown/volume_teardown_rule_spec.rb",
    "torquebox.rb"
  ]

  check_files = (all_files - excluded_files).join(" ")

  sh("bundle exec rubocop -f progress -f offenses %s" % [check_files])
end
